Method: Fynd::Actions#fprintf

Defined in:
lib/fynd/actions.rb

#fprintf(file, format) ⇒ Object

True; like -printf but write to file like -fprint. The output file is always created, even if the predicate is never matched. See the UNUSUAL FILENAMES section for information about how unusual characters in filenames are handled.



80
81
# File 'lib/fynd/actions.rb', line 80

def fprintf(file, format)
end